promqllint

package module
v0.0.0-...-4cfe7e3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 27, 2019 License: MIT Imports: 1 Imported by: 0

README

promqllint

A web-based linter for the PromQL (Prometheus Query Language). Hosted on promqllint.com.

Requirements

  • Go 1.12

Deployment

Although promqllint can be deployed anywhere, it comes with a basic Google App Engine configuration out of the box. After authorizing with a service account or user account account, it's easily deployed using the gcloud SDK:

gcloud app deploy

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Expr

type Expr struct {
	// Raw is the node that was parsed to this expression.
	Raw string
	// Type is the type of this expression, e.g. "vector".
	Type string
}

Expr is a parsed promql expression.

type ParseErr

type ParseErr struct {
	Line, Pos int
	Err       error
}

ParseErr wraps a parsing error with line and position context.

func (*ParseErr) Error

func (e *ParseErr) Error() string

Directories

Path Synopsis
cmd
web command
internal

Jump to